SystemOrganization addCategory: #ConfigurationOfStripe!

Object subclass: #ConfigurationOfStripe
	instanceVariableNames: 'project'
	classVariableNames: 'LastVersionLoad'
	poolDictionaries: ''
	category: 'ConfigurationOfStripe'!

!ConfigurationOfStripe commentStamp: 'PaulDeBruicker 6/1/2012 17:18' prior: 0!
On Pharo you can use Zodiac in conjunction with the SqueakSSLPlugin to communicate with Stripe through HTTPS.  But on Gemstone you must either proxy the HTTPS traffic through a webserver (nginx, apache) or use stunnel.

As far as how things behave between the two platforms there should be no differences.  


You'll also need a port opened for your server to receive the Stripe API WebHooks if you want them.  

!

!ConfigurationOfStripe class methodsFor: 'development support' stamp: 'PaulDeBruicker 10/25/2011 17:32'!
DevelopmentSupport

"See the methods in the 'development support' category on the class-side of MetacelloBaseConfiguration. Decide what development support methods you would like to use and copy them the the class-side of your configuration."
	<apiDocumentation>
! !

!ConfigurationOfStripe class methodsFor: 'private' stamp: 'PaulDeBruicker 10/25/2011 17:32'!
baseConfigurationClassIfAbsent: aBlock

	^Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			self ensureMetacelloBaseConfiguration.
			Smalltalk at: #MetacelloBaseConfiguration ifAbsent: aBlock ].
! !

!ConfigurationOfStripe class methodsFor: 'private' stamp: 'PaulDeBruicker 10/25/2011 17:32'!
ensureMetacello

	(self baseConfigurationClassIfAbsent: []) ensureMetacello! !

!ConfigurationOfStripe class methodsFor: 'private' stamp: 'PaulDeBruicker 10/25/2011 17:32'!
ensureMetacelloBaseConfiguration

	Smalltalk
		at: #MetacelloBaseConfiguration
		ifAbsent: [ 
			| repository version |
			repository := MCHttpRepository location: 'http://seaside.gemstone.com/ss/metacello' user: '' password: ''.
			repository
				versionReaderForFileNamed: 'Metacello-Base-DaleHenrichs.2.mcz'
				do: [ :reader | 
					version := reader version.
					version load.
					version workingCopy repositoryGroup addRepository: repository ] ]! !

!ConfigurationOfStripe class methodsFor: 'metacello tool support' stamp: 'PaulDeBruicker 10/25/2011 17:32'!
isMetacelloConfig
	"Answer true and the Metacello tools will operate on you"
	
	^true! !

!ConfigurationOfStripe class methodsFor: 'loading' stamp: 'PaulDeBruicker 10/25/2011 17:32'!
load
	"Load the #stable version defined for this platform. The #stable version is the version that is recommended to be used on this platform."

	"self load"

	<apiDocumentation>
	^(self project version: #stable) load! !

!ConfigurationOfStripe class methodsFor: 'loading' stamp: 'PaulDeBruicker 10/25/2011 17:32'!
loadBleedingEdge
	"Load the latest versions of the mcz files defined for this project. It is not likely that the #bleedingEdge has been tested."

	"self loadBleedingEdge"

	<apiDocumentation>
	^(self project version: #bleedingEdge) load! !

!ConfigurationOfStripe class methodsFor: 'loading' stamp: 'PaulDeBruicker 10/25/2011 17:32'!
loadDevelopment
	"Load the #development version defined for this platform. The #development version will change over time and is not expected to be stable."

	"self loadDevelopment"

	<apiDocumentation>
	^(self project version: #development) load! !

!ConfigurationOfStripe class methodsFor: 'accessing' stamp: 'PaulDeBruicker 10/25/2011 17:32'!
project

	^self new project! !

!ConfigurationOfStripe class methodsFor: 'development support' stamp: 'PaulDeBruicker 10/25/2011 17:32'!
validate
	"Check the configuration for Errors, Critical Warnings, and Warnings (see class comment for MetacelloMCVersionValidator for more information). 
	Errors identify specification issues that will result in unexpected behaviour when you load the configuration. 
	Critical Warnings identify specification issues that may result in unexpected behavior when you load the configuration.
	Warnings identify specification issues that are technically correct, but are worth take a look at."

	"self validate"

	<apiDocumentation>
	self ensureMetacello.
	^ ((Smalltalk at: #MetacelloToolBox) validateConfiguration: self debug: #() recurse: false) explore! !

!ConfigurationOfStripe methodsFor: 'baselines' stamp: 'PaulDeBruicker 12/16/2011 18:31'!
baseline10: spec
	<version: '1.0-baseline'>

	spec for: #'common' do: [
		spec blessing: #'baseline'.
		spec repository: 'http://www.squeaksource.com/Stripe'.
		spec 
			project: 'Zinc-Zodiac' with: [
				spec
					className: 'ConfigurationOfZincHTTPComponents';
					versionString: #'stable';
					loads:#('Zinc-Zodiac');
					repository: 'http://www.squeaksource.com/ZincHTTPComponents' ];
			project: 'Seaside30' with: [
				spec
					className: 'ConfigurationOfSeaside30';
					versionString: #'stable';
					repository: 'http://www.squeaksource.com/MetacelloRepository' ];
			package: 'Stripe' with: [
				spec requires: #('Seaside30'  'Zinc-Zodiac' ). ].
		spec 
			group: 'default' with: #('Core' );
			group: 'Core' with: #('Stripe' ).  ].
! !

!ConfigurationOfStripe methodsFor: 'baselines' stamp: 'PaulDeBruicker 6/1/2012 17:01'!
baseline11: spec
	<version: '1.1-baseline'>
	spec
		for: #common
		do: [ 
			spec blessing: #baseline.
			spec repository: 'http://www.squeaksource.com/Stripe'.
			spec
				project: 'Seaside30'
					with: [ 
							spec
								className: 'ConfigurationOfSeaside30';
								versionString: #stable;
								repository: 'http://www.squeaksource.com/MetacelloRepository' ];
				project: 'ZincHTTPComponents'
					with: [ 
							spec
								className: 'ConfigurationOfZincHTTPComponents';
								versionString: #stable;
								repository: 'http://www.squeaksource.com/ZincHTTPComponents' ].
			spec
				package: 'Stripe' with: [ spec requires: #('ZincHTTPComponents') ];
				package: 'Stripe-Tests' with: [ spec requires: #('Stripe') ];
				package: 'Stripe-Seaside' with: [ spec requires: #('Seaside30' 'Stripe') ].
			spec
				group: 'default' with: #('Core');
				group: 'Core' with: #('Stripe');
				group: 'Tests' with: #('Stripe-Tests');
				group: 'Seaside-Example' with: #('Stripe-Seaside');
				group: 'Dev' with: #('Stripe-Tests' 'Stripe-Seaside') ].
	spec
		for: #pharo
		do: [ 
			spec package: 'Zodiac-Core' with: [ spec repository: 'http://www.squeaksource.com/Zodiac' ].
			spec group: 'Stripe-Zodiac' with: #('Zodiac' 'Stripe') ]! !

!ConfigurationOfStripe methodsFor: 'symbolic versions' stamp: 'PaulDeBruicker 6/1/2012 17:46'!
development: spec
	<symbolicVersion: #'development'>

	spec for: #'common' version: '1.1'.
! !

!ConfigurationOfStripe methodsFor: 'versions' stamp: 'PaulDeBruicker 10/25/2011 19:33'!
initializeEnvironment
	ZnNetworkingUtils default: ZnZodiacNetworkingUtils new. ! !

!ConfigurationOfStripe methodsFor: 'accessing' stamp: 'PaulDeBruicker 10/25/2011 17:32'!
project

	^ project ifNil: [ | constructor |
		"Bootstrap Metacello if it is not already loaded"
		(self class baseConfigurationClassIfAbsent: []) ensureMetacello.
		"Construct Metacello project"
		constructor := (Smalltalk at: #MetacelloVersionConstructor) on: self.
		project := constructor project.
		project loadType: #linear. "change to #atomic if desired"
		project ]! !

!ConfigurationOfStripe methodsFor: 'symbolic versions' stamp: 'PaulDeBruicker 10/25/2011 17:38'!
stable: spec
	<symbolicVersion: #'stable'>

	spec for: #'common' version: '1.0'.
! !

!ConfigurationOfStripe methodsFor: 'versions' stamp: 'PaulDeBruicker 12/16/2011 18:32'!
version10: spec
	<version: '1.0' imports: #('1.0-baseline')>
	spec
		for: #common
		do: [ 
			spec blessing: #release.
			spec description: 'initial version'.
			spec author: 'PaulDeBruicker'.
			spec postLoadDoIt: #initializeEnvironment.
			spec timestamp: '10/25/2011 17:36'.
			spec
				project: 'Zinc-Zodiac' with: #stable;
				project: 'Seaside30' with: #stable.
			spec
				package: 'Stripe' with: 'Stripe-PaulDeBruicker.8' ]! !

!ConfigurationOfStripe methodsFor: 'versions' stamp: 'PaulDeBruicker 6/1/2012 17:46'!
version11: spec
	<version: '1.1' imports: #('1.1-baseline' )>

	spec for: #'common' do: [
		spec blessing: #'development'.
		spec description: 'includes WebHooks'.
		spec author: 'PaulDeBruicker'.
		spec timestamp: '6/1/2012 17:46'.
		spec 
			project: 'Seaside30' with: #'stable';
			project: 'ZincHTTPComponents' with: #'stable'.
		spec 
			package: 'Stripe' with: 'Stripe-PaulDeBruicker.10';
			package: 'Stripe-Tests' with: 'Stripe-Tests-PaulDeBruicker.1';
			package: 'Stripe-Seaside' with: 'Stripe-Seaside-PaulDeBruicker.2'. ].

	spec for: #'pharo' do: [
		spec package: 'Zodiac-Core' with: 'Zodiac-Core-SvenVanCaekenberghe.17'. ].
! !
